Introduction
============

Python module ``scinumtools`` originated as a private collection of most repeated routines used in my everyday programming and analysis of numerical simulations. Since I find these routines and patterns usefull, I decided to collect them into a single Python module, that can be quickly imported into any project and anybody can use it.

This package does not claim to give the best possible algorythms or solutions for the given problems. It marely reflects my preference and aesthetic feelings in Python programming. Any constructive comments, suggestions and improvements are heartily welcommed.

``scinumtools`` is currently in it's 1.x.x version. It is planned that version 2.x.x will make use of C++ to further accelerate selected algorythms.

The module is divided into several sections:

data
  collection of routines for manipulation with data

math
  mathematical routines and solvers

phys
  physical routines and manipulation with dimensional quantities

stats
  statistical routines

structs
  structures beyond basic Python

